Learn R Programming

palasso (version 1.0.0)

.cor: Correlation

Description

Calculates the correlation between the response and the covariates. Shrinks the correlation coefficients for each covariate set separately.

Usage

.cor(y, x, args)

Value

list of vectors

Arguments

y

vector of length \(n\)

x

matrix with \(n\) rows and \(p\) columns

args

options for paired lasso: list of arguments (output from .dims and .args)

Examples

Run this code
NA

Run the code above in your browser using DataLab