Learn R Programming

palasso (version 1.0.0)

.dims: Dimensionality

Description

This function extracts the dimensions.

Usage

.dims(y, X, args = NULL)

Value

The function .dims extracts the dimensionality. It returns the numbers of samples, covariate pairs and covariate sets. It also returns the number of weighting schemes, and the names of these weighting schemes.

Arguments

y

response: vector of length \(n\)

X

covariates: list of matrices, each with \(n\) rows (samples) and \(p\) columns (variables)

args

options for paired lasso: list of arguments (output from .dims and .args)

Examples

Run this code
NA

Run the code above in your browser using DataLab