powered by
Calculates the correlation between the response and the covariates. Shrinks the correlation coefficients for each covariate set separately.
.cor(y, x, args)
list of vectors
vector of length \(n\)
matrix with \(n\) rows and \(p\) columns
options for paired lasso: list of arguments (output from .dims and .args)
NA
Run the code above in your browser using DataLab